Enum sxd_xpath::ExpressionError
[−]
[src]
pub enum ExpressionError {
NotANodeset,
UnknownFunction(String),
UnknownVariable(String),
FunctionEvaluation(Error),
}Variants
NotANodesetUnknownFunction(String)UnknownVariable(String)FunctionEvaluation(Error)Trait Implementations
impl Clone for Error[src]
fn clone(&self) -> Error
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Debug for Error[src]
impl PartialEq for Error[src]
fn eq(&self, __arg_0: &Error) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Error) -> bool
This method tests for !=.
impl Hash for Error[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Error for Error[src]
fn description(&self) -> &str
A short description of the error. Read more
fn cause(&self) -> Option<&Error>1.0.0
The lower-level cause of this error, if any. Read more